AsyncDebug

Trait AsyncDebug 

pub trait AsyncDebug { }
AsyncDebug trait, this just marks the struct or enum as having AsyncDebug capabilities, the actual implementation is in an inherent impl

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors